@@ -50,3 +50,9 @@ for tmpSection in tmpConf.sections():
             tmpVal = int(tmpVal)
         # update dict
         setattr(tmpSelf,tmpKey,tmpVal)
+    # database info via env
+    if tmpSection == 'db':
+        if 'PANDA_DB_HOST' in os.environ:
+            tmpSelf.dbhost = os.environ['PANDA_DB_HOST']
+        if 'PANDA_DB_PASSWORD' in os.environ:
+            tmpSelf.dbpasswd = os.environ['PANDA_DB_PASSWORD']
\ No newline at end of file
