@@ -1,4 +1,5 @@
 import copy
+import math
 import random
 
 from six import iteritems
@@ -421,7 +422,12 @@ class InputChunk:
         except Exception:
             return 0
 
-
+    # get value with unit
+    def get_value_str(self, value):
+        try:
+            return '{}MB'.format(int(math.ceil(value/1024/1024)))
+        except Exception:
+            return None
 
     # get subchunk with a selection criteria
     def getSubChunk(self,siteName,maxNumFiles=None,maxSize=None,
@@ -440,7 +446,8 @@ class InputChunk:
                     splitByFields=None,
                     tmpLog=None,
                     useDirectIO=False,
-                    maxDiskSize=None):
+                    maxDiskSize=None,
+                    enableLog=False):
         # check if there are unused files/events
         if not self.checkUnused():
             return None
@@ -504,6 +511,7 @@ class InputChunk:
         nSecFilesMap   = {}
         nSecEventsMap  = {}
         numMaster      = 0
+        masterSize     = 0
         outSizeMap     = {}
         lumiBlockNr    = None
         newLumiBlockNr = False
@@ -511,6 +519,7 @@ class InputChunk:
         inputFileSet   = set()
         fieldStr       = None
         diskSize       = 0
+        dumpStr = ''
         while (maxNumFiles is None or (not dynNumEvents and inputNumFiles <= maxNumFiles) or \
                    (dynNumEvents and len(inputFileSet) <= maxNumFiles and inputNumFiles <= maxNumEventRanges)) \
                 and (maxSize is None or (maxSize is not None and fileSize <= maxSize)) \
@@ -571,6 +580,7 @@ class InputChunk:
                     diskSize += tmpOutSize
                     if not dynNumEvents or tmpFileSpec.lfn not in inputFileSet:
                         fileSize += long(tmpFileSpec.fsize)
+                        masterSize += long(tmpFileSpec.fsize)
                         if not useDirectIO:
                             diskSize += long(tmpFileSpec.fsize)
                     outSizeMap[self.masterDataset.datasetID] += long(sizeGradients * effectiveNumEvents)
@@ -580,6 +590,7 @@ class InputChunk:
                     diskSize += tmpOutSize
                     if not dynNumEvents or tmpFileSpec.lfn not in inputFileSet:
                         fileSize += long(tmpFileSpec.fsize)
+                        masterSize += long(tmpFileSpec.fsize)
                         if not useDirectIO:
                             diskSize += long(tmpFileSpec.fsize)
                     outSizeMap[self.masterDataset.datasetID] += long(sizeGradients * effectiveFsize)
@@ -711,21 +722,27 @@ class InputChunk:
             firstLoop = False
             # check if there are unused files/evets
             if not self.checkUnused():
+                dumpStr = 'no more files'
                 break
             # break if nFilesPerJob is used as multiplicand
             if nFilesPerJob is not None and not respectLB:
+                dumpStr = 'nFilesPerJob specified'
                 break
-            # boundayID is changed
+            # boundaryID is changed
             if newBoundaryID:
+                dumpStr = 'new BoundaryID'
                 break
             # LB is changed
             if newLumiBlockNr:
+                dumpStr = 'new LB'
                 break
             # event jump
             if eventJump:
+                dumpStr = 'event jump'
                 break
             # distributed files are unavailable
             if not siteAvailable:
+                dumpStr = 'distributed files are unavailable'
                 break
             primaryHasEvents = False
             # check master in the next loop
@@ -741,6 +758,7 @@ class InputChunk:
             newBoundaryIDs    = set()
             newInputFileSet   = copy.copy(inputFileSet)
             newDiskSize       = diskSize
+            new_nSecEventsMap = copy.copy(nSecEventsMap)
             if self.masterDataset.datasetID not in newOutSizeMap:
                 newOutSizeMap[self.masterDataset.datasetID] = 0
             for tmpFileSpec in self.masterDataset.Files[datasetUsage['used']:datasetUsage['used']+multiplicand]:
@@ -752,6 +770,7 @@ class InputChunk:
                     if newNextStartEvent is not None and newNextStartEvent != tmpFileSpec.startEvent:
                         # no files in the next loop
                         if newInputNumFiles == 0:
+                            dumpStr = 'no files with continuous events in the next loop'
                             terminateFlag = True
                         break
                     newNextStartEvent = tmpFileSpec.endEvent + 1
@@ -760,12 +779,14 @@ class InputChunk:
                         and useBoundary['inSplit'] != 3:
                     # no files in the next loop
                     if newInputNumFiles == 0:
+                        dumpStr = 'no files with the same BoundaryID in the next loop'
                         terminateFlag = True
                     break
                 # check LB
                 if respectLB and lumiBlockNr is not None and lumiBlockNr != tmpFileSpec.lumiBlockNr:
                     # no files in the next loop
                     if newInputNumFiles == 0:
+                        dumpStr = 'no files with the same LB in the next loop'
                         terminateFlag = True
                     break
                 # check field
@@ -774,6 +795,7 @@ class InputChunk:
                     if tmpFieldStr != fieldStr:
                         # no files in the next loop
                         if newInputNumFiles == 0:
+                            dumpStr = 'no files with the same LFN field in the next loop'
                             terminateFlag = True
                         break
                 # check for distributed datasets
@@ -835,6 +857,7 @@ class InputChunk:
                     newBoundaryIDs.add(tmpFileSpec.boundaryID)
             # check secondaries
             firstSecondary = True
+            newSecMap = {}
             for datasetSpec in self.secondaryDatasetList:
                 if datasetSpec.datasetID not in newOutSizeMap:
                     newOutSizeMap[datasetSpec.datasetID] = 0
@@ -843,27 +866,42 @@ class InputChunk:
                     if splitWithBoundaryID and boundaryID is not None and boundaryID != tmpFileSpec.boundaryID \
                             and useBoundary['inSplit'] != 3:
                         break
+                    newSecMap.setdefault(datasetSpec.datasetID, {'in_size': 0, 'out_size': 0})
                     newNumSecondary = datasetSpec.getNumMultByRatio(newNumMaster) - nSecFilesMap[datasetSpec.datasetID]
+                    if newNumSecondary < 0:
+                        newNumSecondary = 0
+                    newSecMap[datasetSpec.datasetID]['nSec'] = newNumSecondary
+                    newSecMap[datasetSpec.datasetID]['nSecReal'] = 0
                     datasetUsage = self.datasetMap[datasetSpec.datasetID]
-                    for tmpFileSpec in datasetSpec.Files[datasetUsage['used']:datasetUsage['used']+nSecondary]:
+                    for tmpFileSpec in datasetSpec.Files[datasetUsage['used']:datasetUsage['used']+newNumSecondary]:
                         # check boundaryID
                         if splitWithBoundaryID and boundaryID is not None and boundaryID != tmpFileSpec.boundaryID \
                                 and tmpFileSpec.boundaryID not in boundaryIDs and tmpFileSpec.boundaryID not in newBoundaryIDs:
                             break
+                        # check ratio
+                        if datasetSpec.getEventRatio() is not None and newInputNumEvents > 0:
+                            if float(new_nSecEventsMap[datasetSpec.datasetID]) / float(newInputNumEvents) \
+                                    >= datasetSpec.getEventRatio():
+                                break
                         newFileSize += tmpFileSpec.fsize
+                        newSecMap[datasetSpec.datasetID]['in_size'] += tmpFileSpec.fsize
+                        newSecMap[datasetSpec.datasetID]['nSecReal'] += 1
                         if not useDirectIO:
                             newDiskSize += tmpFileSpec.fsize
                         if sizeGradientsPerInSize is not None:
                             tmpOutSize = (tmpFileSpec.fsize * sizeGradientsPerInSize)
                             newFileSize += tmpOutSize
                             newDiskSize += tmpOutSize
-                            newOutSizeMap[datasetSpec.datasetID] += (tmpFileSpec.fsize * sizeGradientsPerInSize)
+                            newOutSizeMap[datasetSpec.datasetID] += tmpOutSize
+                            newSecMap[datasetSpec.datasetID]['out_size'] += tmpOutSize
                         # the number of events
                         if firstSecondary and maxNumEvents is not None and not primaryHasEvents:
                             if tmpFileSpec.startEvent is not None and tmpFileSpec.endEvent is not None:
                                 newInputNumEvents += (tmpFileSpec.endEvent - tmpFileSpec.startEvent + 1)
                             elif tmpFileSpec.nEvents is not None:
                                 newInputNumEvents += tmpFileSpec.nEvents
+                        if tmpFileSpec.nEvents is not None:
+                            new_nSecEventsMap[datasetSpec.datasetID] += tmpFileSpec.nEvents
                     firstSecondary = False
             # termination
             if terminateFlag:
@@ -874,10 +912,34 @@ class InputChunk:
                                              or (dynNumEvents and (len(newInputFileSet) > maxNumFiles or newInputNumFiles > maxNumEventRanges)))) \
                     or (maxSize is not None and newFileSize > maxSize) \
                     or (maxSize is not None and newOutSize < minOutSize and maxSize-minOutSize < newFileSize-newOutSize) \
-                    or (maxWalltime > 0 and newExpWalltime > maxWalltime) \
+                    or (maxWalltime is not None and 0 < maxWalltime < newExpWalltime) \
                     or (maxNumEvents is not None and newInputNumEvents > maxNumEvents) \
                     or (maxOutSize is not None and self.getOutSize(newOutSizeMap) > maxOutSize) \
                     or (maxDiskSize is not None and newDiskSize > maxDiskSize):
+                dumpStr = 'check for the next loop. '
+                if maxNumFiles is not None and (not dynNumEvents and newInputNumFiles > maxNumFiles):
+                    dumpStr += 'maxNumFiles exceeds maxNumFiles={} inputNumFiles={} newInputNumFiles={}. '.format(
+                        maxNumFiles, inputNumFiles, newInputNumFiles)
+                if maxSize is not None and newFileSize > maxSize:
+                    dumpStr += 'maxSize exceeds maxSize={} fileSize={} masterSize={} newFileSize={} newSecMap={}. '.format(
+                        self.get_value_str(maxSize), self.get_value_str(fileSize), self.get_value_str(masterSize),
+                        self.get_value_str(newFileSize), str(newSecMap))
+                if maxSize is not None and newOutSize < minOutSize and maxSize-minOutSize < newFileSize-newOutSize:
+                    dumpStr += 'maxSize exceeds with outSize maxSize={} minOutSize={} fileSize={} newFileSize={} newOutSize={}. '.\
+                        format(self.get_value_str(maxSize), self.get_value_str(minOutSize), self.get_value_str(fileSize),
+                               self.get_value_str(newFileSize), self.get_value_str(newOutSize))
+                if maxWalltime is not None and 0 < maxWalltime < newExpWalltime:
+                    dumpStr += 'maxWalltime exceeds maxWalltime={} expWalltime={} newExpWalltime={}. '.format(
+                        maxWalltime, expWalltime, newExpWalltime)
+                if maxNumEvents is not None and newInputNumEvents > maxNumEvents:
+                    dumpStr += 'maxNumEvents exceeds maxNumEvents={} inputNumEvents={} newInputNumEvents={}. '.format(
+                        maxNumEvents, inputNumEvents, newInputNumEvents)
+                if maxOutSize is not None and self.getOutSize(newOutSizeMap) > maxOutSize:
+                    dumpStr += 'maxOutSize exceeds maxOutSize={} getOutSize(newOutSizeMap)={}. '.format(
+                        self.get_value_str(maxOutSize), self.get_value_str(self.getOutSize(newOutSizeMap)))
+                if maxDiskSize is not None and newDiskSize > maxDiskSize:
+                    dumpStr += 'maxDiskSize exceeds maxDiskSize={} diskSize={} newDiskSize={}. '.format(
+                        self.get_value_str(maxDiskSize), self.get_value_str(diskSize), self.get_value_str(newDiskSize))
                 break
         # reset nUsed for repeated datasets
         for tmpDatasetID,datasetUsage in iteritems(self.datasetMap):
@@ -906,6 +968,11 @@ class InputChunk:
             # add to return map
             tmpDatasetSpec = self.getDatasetWithID(tmpDatasetID)
             returnList.append((tmpDatasetSpec,tmpRetList))
+        # dump only problematic splitting
+        if enableLog and tmpLog and returnList:
+            if maxNumEvents is not None and inputNumEvents < maxNumEvents:
+                tmpLog.debug('not enough events {}>{} at {}: numMaster={}. {}'.format(maxNumEvents, inputNumEvents,
+                                                                                      siteName, numMaster, dumpStr))
         # return
         return returnList
 
