@@ -47,9 +47,12 @@ class JediTaskSpec(object):
         'allowPartialFinish' : 'AP',
         'altStageOut'        : 'AT',
         'avoidVP'            : 'AV',
+        'maxCoreCount'       : 'CC',
+        'cloudAsVO'          : 'CV',
         'ddmBackEnd'         : 'DE',
         'disableAutoFinish'  : 'DF',
         'disableReassign'    : 'DI',
+        'debugMode'          : 'DM',
         'disableAutoRetry'   : 'DR',
         'dynamicNumEvents'   : 'DY',
         'nEsConsumers'       : 'EC',
@@ -94,6 +97,7 @@ class JediTaskSpec(object):
         'orderByLB'          : 'OL',
         'osMatching'         : 'OS',
         'onlyTagsForFC'      : 'OT',
+        'pushStatusChanges'  : 'PC',
         'pfnList'            : 'PL',
         'putLogToOS'         : 'PO',
         'runUntilClosed'     : 'RC',
@@ -108,6 +112,7 @@ class JediTaskSpec(object):
         'switchEStoNormal'   : 'SE',
         'stayOutputOnSite'   : 'SO',
         'scoutSuccessRate'   : 'SS',
+        'useSecrets'         : 'ST',
         'segmentedWork'      : 'SW',
         'totNumJobs'         : 'TJ',
         'tgtMaxOutputForNG'  : 'TN',
@@ -1709,6 +1714,14 @@ class JediTaskSpec(object):
                 return True
         return False
 
+    # debug mode
+    def is_debug_mode(self):
+        if self.splitRule is not None:
+            tmpMatch = re.search(self.splitRuleToken['debugMode']+'=(\d+)', self.splitRule)
+            if tmpMatch is not None:
+                return True
+        return False
+
     # multi-step execution
     def is_multi_step_exec(self):
         if self.splitRule is not None:
@@ -1793,3 +1806,41 @@ class JediTaskSpec(object):
         # remove log URL
         tmpStr = re.sub('<a href.+</a> : ', '', self.origErrorDialog)
         return tmpStr.split('. ')[-1]
+
+    # check if secrets are used
+    def use_secrets(self):
+        if self.splitRule is not None:
+            if re.search(self.splitRuleToken['useSecrets']+'=(\d+)', self.splitRule):
+                return True
+        return False
+
+    # get max core count
+    def get_max_core_count(self):
+        if self.splitRule is not None:
+            tmpMatch = re.search(self.splitRuleToken['maxCoreCount']+'=(\d+)', self.splitRule)
+            if tmpMatch is not None:
+                return int(tmpMatch.group(1))
+        return None
+
+    # push status changes
+    def push_status_changes(self):
+        return push_status_changes(self.splitRule)
+
+    # use cloud as VO
+    def cloud_as_vo(self):
+        if self.splitRule is not None:
+            if re.search(self.splitRuleToken['cloudAsVO']+'=(\d+)', self.splitRule):
+                return True
+        return False
+
+
+# utils
+
+# check if push status changes without class instance
+def push_status_changes(split_rule):
+    if not split_rule:
+        return False
+    tmpMatch = re.search(JediTaskSpec.splitRuleToken['pushStatusChanges'] + r'=(\d+)', split_rule)
+    if not tmpMatch or int(tmpMatch.group(1)) <= 0:
+        return False
+    return True
