@@ -4,12 +4,19 @@ import sys
 import datetime
 import json
 import traceback
+import requests
 
 try:
     from urllib.request import urlopen
 except ImportError:
     from urllib2 import urlopen
 
+try:
+    import urllib3
+    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+except Exception:
+    pass
+
 from six import iteritems
 
 from pandajedi.jedicore.MsgWrapper import MsgWrapper
@@ -21,6 +28,9 @@ from rucio.common.exception import UnsupportedOperation,DataIdentifierNotFound,D
     DuplicateRule,DuplicateContent, InvalidObject
 
 from pandaserver.dataservice import DataServiceUtils
+from pandaserver.srvcore import CoreUtils
+
+from pandajedi.jediconfig import jedi_config
 
 # logger
 from pandacommon.pandalogger.PandaLogger import PandaLogger
@@ -50,14 +60,6 @@ class AtlasDDMClient(DDMClientBase):
         # pid
         self.pid = os.getpid()
 
-    # get a parsed certificate DN
-    def parse_dn(self, tmpDN):
-        if tmpDN is not None:
-            tmpDN = re.sub('/CN=limited proxy','',tmpDN)
-            tmpDN = re.sub('(/CN=proxy)+$', '', tmpDN)
-            # tmpDN = re.sub('(/CN=\d+)+$', '', tmpDN)
-        return tmpDN
-
     # get files in dataset
     def getFilesInDataset(self, datasetName, getNumEvents=False, skipDuplicate=True,
                           ignoreUnknown=False, longFormat=False, lfn_only=False):
@@ -433,10 +435,19 @@ class AtlasDDMClient(DDMClientBase):
                     raise RuntimeError(rucio_lfn_to_rse_map)
             else:
                 rucio_lfn_to_rse_map = dict()
-                if (not file_scan_in_container and is_container):
+                if not file_scan_in_container and is_container:
+                    # remove incomplete
+                    detailed_comp_replica_map = dict()
+                    for tmp_ds_name, tmp_ds_value in iteritems(detailed_replica_map):
+                        new_map = {}
+                        for tmp_k, tmp_v in iteritems(tmp_ds_value):
+                            if tmp_v[0]['total'] and tmp_v[0]['total'] == tmp_v[0]['found']:
+                                new_map[tmp_k] = tmp_v
+                        if new_map:
+                            detailed_comp_replica_map[tmp_ds_name] = new_map
                     # make file list from detailed replica map
                     files_in_container = {}
-                    for tmp_ds_name in detailed_replica_map.keys():
+                    for tmp_ds_name in detailed_comp_replica_map.keys():
                         tmp_status, tmp_files = self.getFilesInDataset(tmp_ds_name, ignoreUnknown=True, lfn_only=True)
                         if tmp_status != self.SC_SUCCEEDED:
                             raise RuntimeError(tmp_files)
@@ -444,8 +455,9 @@ class AtlasDDMClient(DDMClientBase):
                             files_in_container[tmp_lfn] = tmp_ds_name
                     for tmp_file in dataset_spec.Files:
                         if tmp_file.lfn in files_in_container and \
-                                files_in_container[tmp_file.lfn] in detailed_replica_map:
-                            rucio_lfn_to_rse_map[tmp_file.lfn] = detailed_replica_map[files_in_container[tmp_file.lfn]]
+                                files_in_container[tmp_file.lfn] in detailed_comp_replica_map:
+                            rucio_lfn_to_rse_map[tmp_file.lfn] = \
+                                detailed_comp_replica_map[files_in_container[tmp_file.lfn]]
 
             # initialize the return map and add complete/cached replicas
             return_map = {}
@@ -955,30 +967,38 @@ class AtlasDDMClient(DDMClientBase):
             return errCode, '{0} : {1}'.format(methodName, errMsg)
 
     # finger
-    def finger(self,userName):
+    def finger(self, dn):
         methodName = 'finger'
         methodName += ' pid={0}'.format(self.pid)
-        methodName = '{0} userName={1}'.format(methodName,userName)
+        methodName = '{0} userName={1}'.format(methodName, dn)
         tmpLog = MsgWrapper(logger,methodName)
         tmpLog.debug('start')
         try:
-            # cleanup DN
-            userName = self.parse_dn(userName)
             # get rucio API
             client = RucioClient()
             userInfo = None
+            x509_user_name = CoreUtils.get_bare_dn(dn)
+            oidc_user_name = CoreUtils.get_id_from_dn(dn)
+            if oidc_user_name == x509_user_name:
+                oidc_user_name = None
+            else:
+                x509_user_name = None
             for accType in ['USER', 'GROUP']:
-                for i in client.list_accounts(account_type=accType, identity=userName):
-                    userInfo = {'nickname':i['account'],
-                                'email':i['email']}
-                    break
-                if userInfo is None:
-                    # remove /CN=\d
-                    userName = re.sub('(/CN=\d+)+$','',userName)
+                if x509_user_name is not None:
+                    userName = x509_user_name
                     for i in client.list_accounts(account_type=accType, identity=userName):
                         userInfo = {'nickname':i['account'],
                                     'email':i['email']}
                         break
+                    if userInfo is None:
+                        # remove /CN=\d
+                        userName = CoreUtils.get_bare_dn(dn, keep_digits=False)
+                        for i in client.list_accounts(account_type=accType, identity=userName):
+                            userInfo = {'nickname':i['account'],
+                                        'email':i['email']}
+                            break
+                else:
+                    userName = oidc_user_name
                 try:
                     if userInfo is None:
                         i = client.get_account(userName)
@@ -1037,8 +1057,6 @@ class AtlasDDMClient(DDMClientBase):
         try:
             # get rucio API
             client = RucioClient()
-            # cleanup DN
-            owner = self.parse_dn(owner)
             # get scope and name
             scope,dsn = self.extract_scope(datasetName)
             # lifetime
@@ -1073,7 +1091,7 @@ class AtlasDDMClient(DDMClientBase):
             errCode, errMsg = self.checkError(errType)
             tmpLog.error(errMsg)
             return errCode, '{0} : {1}'.format(methodName, errMsg)
-        tmpLog.debug('done')
+        tmpLog.debug('done for owner={}'.format(owner))
         return self.SC_SUCCEEDED,True
 
     # delete dataset
@@ -1424,9 +1442,16 @@ class AtlasDDMClient(DDMClientBase):
         # get json
         try:
             tmpLog.debug('start')
-            with open('/cvmfs/atlas.cern.ch/repo/sw/local/etc/cric_ddmendpoints.json') as f:
-                ddd = json.load(f)
-                self.endPointDict = {k: ddd[k] for k in ddd if ddd[k]['state'] == 'ACTIVE'}
+            if hasattr(jedi_config.ddm, 'endpoints_json_path'):
+                tmp_path = jedi_config.ddm.endpoints_json_path
+            else:
+                tmp_path = '/cvmfs/atlas.cern.ch/repo/sw/local/etc/cric_ddmendpoints.json'
+            if tmp_path.startswith('http'):
+                ddd = requests.get(tmp_path, verify=False).json()
+            else:
+                with open(tmp_path) as f:
+                    ddd = json.load(f)
+            self.endPointDict = {k: ddd[k] for k in ddd if ddd[k]['state'] == 'ACTIVE'}
             tmpLog.debug('got {0} endpoints '.format(len(self.endPointDict)))
         except Exception as e:
             errStr = 'failed to update EP with {0}'.format(str(e))
@@ -1532,8 +1557,6 @@ class AtlasDDMClient(DDMClientBase):
         tmpLog.debug('start')
         retVal = True, None
         try:
-            # cleanup DN
-            userName = self.parse_dn(userName)
             # get rucio API
             client = RucioClient()
             tmpStat, user_info = self.finger(userName)
