@@ -141,10 +141,12 @@ class ContentsFeederThread (WorkerThread):
                         # get task parameters
                         taskParam = self.taskBufferIF.getTaskParamsWithID_JEDI(jediTaskID)
                         taskParamMap = RefinerUtils.decodeJSON(taskParam)
-                    except Exception:
-                        errtype,errvalue = sys.exc_info()[:2]
-                        tmpLog.error('task param conversion from json failed with {0}:{1}'.format(errtype.__name__,errvalue))
-                        taskBroken = True
+                    except Exception as e:
+                        tmpLog.error('task param conversion from json failed with {}'.format(str(e)))
+                        # unlock
+                        tmpStat = self.taskBufferIF.unlockSingleTask_JEDI(jediTaskID, self.pid)
+                        tmpLog.debug('unlocked with {}'.format(tmpStat))
+                        continue
                     # renaming of parameters
                     if 'nEventsPerInputFile' in taskParamMap:
                         taskParamMap['nEventsPerFile'] = taskParamMap['nEventsPerInputFile']
@@ -167,7 +169,7 @@ class ContentsFeederThread (WorkerThread):
                     parentOutDatasets = set()
                     if taskSpec.noWaitParent() and taskSpec.parent_tid not in [None,taskSpec.jediTaskID]:
                         tmpStat = self.taskBufferIF.checkParentTask_JEDI(taskSpec.parent_tid)
-                        if tmpStat == 'running':
+                        if tmpStat is None or tmpStat == 'running':
                             noWaitParent = True
                             # get output datasets from parent task
                             tmpParentStat,tmpParentOutDatasets = self.taskBufferIF.getDatasetsWithJediTaskID_JEDI(taskSpec.parent_tid,
@@ -187,7 +189,7 @@ class ContentsFeederThread (WorkerThread):
                     checkedMaster = False
                     setFrozenTime = True
                     if not taskBroken:
-                        ddmIF = self.ddmIF.getInterface(taskSpec.vo)
+                        ddmIF = self.ddmIF.getInterface(taskSpec.vo, taskSpec.cloud)
                         origNumFiles = None
                         if 'nFiles' in taskParamMap:
                             origNumFiles = taskParamMap['nFiles']
@@ -255,7 +257,7 @@ class ContentsFeederThread (WorkerThread):
                                     # ignore missing
                                     datasetStatus = 'finished'
                                     # update dataset status
-                                    self.updateDatasetStatus(datasetSpec, datasetStatus, tmpLog)
+                                    self.updateDatasetStatus(datasetSpec, datasetStatus, tmpLog, 'closed')
                                     tmpLog.debug('disabled missing {0}'.format(datasetSpec.datasetName))
                                     continue
                                 # get file list specified in task parameters
@@ -307,12 +309,14 @@ class ContentsFeederThread (WorkerThread):
                                                                          )
                                         tmpLog.debug('got {0} files in {1}'.format(len(tmpRet),tmpDatasetName))
                                         # remove lost files
+                                        """
                                         tmpLostFiles = ddmIF.findLostFiles(tmpDatasetName,tmpRet)
                                         if tmpLostFiles != {}:
                                             tmpLog.debug('found {0} lost files in {1}'.format(len(tmpLostFiles),tmpDatasetName))
                                             for tmpListGUID,tmpLostLFN in iteritems(tmpLostFiles):
                                                 tmpLog.debug('removed {0}'.format(tmpLostLFN))
                                                 del tmpRet[tmpListGUID]
+                                        """
                                     else:
                                         if datasetSpec.isSeqNumber():
                                             # make dummy files for seq_number
@@ -638,11 +642,13 @@ class ContentsFeederThread (WorkerThread):
 
 
     # update dataset
-    def updateDatasetStatus(self,datasetSpec,datasetStatus,tmpLog):
+    def updateDatasetStatus(self,datasetSpec,datasetStatus,tmpLog, datasetState=None):
         # update dataset status
         datasetSpec.status   = datasetStatus
         datasetSpec.lockedBy = None
-        tmpLog.info('update dataset status with {0}'.format(datasetSpec.status))
+        if datasetState:
+            datasetSpec.state = datasetState
+        tmpLog.info('update dataset status to {} state to {}'.format(datasetSpec.status, datasetSpec.state))
         self.taskBufferIF.updateDataset_JEDI(datasetSpec,
                                              {'datasetID':datasetSpec.datasetID,
                                               'jediTaskID':datasetSpec.jediTaskID},
@@ -664,7 +670,7 @@ class ContentsFeederThread (WorkerThread):
                         continue
                     rule_id = task_params_map['prestagingRuleID'][tmp_name]
                 else:
-                    rule_id = self.ddmIF.getInterface(task_spec.vo).getActiveStagingRule(
+                    rule_id = self.ddmIF.getInterface(task_spec.vo, task_spec.cloud).getActiveStagingRule(
                         tmp_scope + ':' + tmp_name)
                     if rule_id is None:
                         continue
