@@ -364,8 +364,18 @@ class TaskRefinerBase (object):
             self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['hpoWorkflow'])
         if 'noLoopingCheck' in taskParamMap and taskParamMap['noLoopingCheck']:
             self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['noLoopingCheck'])
-        if 'encJobParams' in taskParamMap and 'encJobParams' in taskParamMap:
+        if 'encJobParams' in taskParamMap and taskParamMap['encJobParams']:
             self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['encJobParams'])
+        if 'useSecrets' in taskParamMap and taskParamMap['useSecrets']:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['useSecrets'])
+        if 'debugMode' in taskParamMap and taskParamMap['debugMode']:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['debugMode'])
+        if 'pushStatusChanges' in taskParamMap and taskParamMap['pushStatusChanges']:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['pushStatusChanges'])
+        if 'maxCoreCount' in taskParamMap:
+            self.setSplitRule(taskParamMap, 'maxCoreCount', JediTaskSpec.splitRuleToken['maxCoreCount'])
+        if 'cloudAsVO' in taskParamMap:
+            self.setSplitRule(None, 1, JediTaskSpec.splitRuleToken['cloudAsVO'])
         # work queue
         workQueue = None
         if 'workQueueName' in taskParamMap:
@@ -535,12 +545,17 @@ class TaskRefinerBase (object):
                             tmpDatasetNameList = [datasetName]
                             if self.taskSpec.is_work_segmented():
                                 tmpDatasetNameList *= len(taskParamMap['segmentSpecs'])
-                        elif 'expand' in tmpItem and tmpItem['expand'] is True:
-                            # expand dataset container
-                            tmpDatasetNameList = self.ddmIF.getInterface(self.taskSpec.vo).expandContainer(datasetName)
                         else:
-                            # normal dataset name
-                            tmpDatasetNameList = self.ddmIF.getInterface(self.taskSpec.vo).listDatasets(datasetName)
+                            tmpIF = self.ddmIF.getInterface(self.taskSpec.vo, self.taskSpec.cloud)
+                            if not tmpIF:
+                                tmpDatasetNameList = []
+                            else:
+                                if 'expand' in tmpItem and tmpItem['expand'] is True:
+                                    # expand dataset container
+                                    tmpDatasetNameList = tmpIF.expandContainer(datasetName)
+                                else:
+                                    # normal dataset name
+                                    tmpDatasetNameList = tmpIF.listDatasets(datasetName)
                         i_element = 0
                         for elementDatasetName in tmpDatasetNameList:
                             if nIn > 0 or elementDatasetName not in tmpItem['expandedList'] or \
